yarp_latency-test {#master}
-------------------------

## Important Changes

### Yarp companion

#### added command `yarp latency-test`
* `yarp latency-test` performs a latency test exchanging data between a server and a client node